<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dist?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// D
	'dist_description' => 'Insieme di template distribuiti con SPIP 3.',
	'dist_slogan' => 'Template di default di SPIP 3',
];
